"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.authWithJWT = void 0;
const permit_1 = require("permit");
const jsonwebtoken_1 = require("jsonwebtoken");
const api_1 = require("./api");
const responses_1 = require("./http/responses");
const forceHS512 = (jwtOptions) => jwtOptions
    ? Object.assign(Object.assign({}, jwtOptions), { algorithm: 'HS512' }) : { algorithm: 'HS512' };
const forceHS512Verify = (jwtOptions) => jwtOptions
    ? Object.assign(Object.assign({}, jwtOptions), { algorithms: ['HS512'] }) : { algorithms: ['HS512'] };
// decorator creator
const createAuth = (verify, { loader, bearer, authCookieName }) => {
    const permit = new permit_1.Bearer(bearer || {
        query: 'access_token',
    });
    return (req) => __awaiter(void 0, void 0, void 0, function* () {
        const token = authCookieName
            ? req.cookies[authCookieName]
            : permit.check(req);
        if (!token) {
            throw new responses_1.HttpResponseUnauthorized('no token');
        }
        let payload;
        try {
            payload = yield verify(token);
        }
        catch (error) {
            throw new responses_1.HttpResponseUnauthorized('bad token');
        }
        const detail = yield loader(payload);
        if (!detail || !detail.user) {
            throw new responses_1.HttpResponseUnauthorized('no such user');
        }
        return detail;
    });
};
const buildAuth = (verify, MWare, opts) => {
    const auth = createAuth(verify, opts);
    return MWare((req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
        const _a = yield auth(req), { user } = _a, rest = __rest(_a, ["user"]);
        req.user = user;
        req.state = rest;
        next();
    }));
};
const authWithJWT = ({ secret, jwtOptions, loader, bearer, authCookieName, }) => {
    if (!secret) {
        throw new Error('no JWT secret set');
    }
    const resolvedOptions = jwtOptions || {
        expiresIn: '14d',
    };
    const signJWT = (payload) => (0, jsonwebtoken_1.sign)(payload, secret, forceHS512(resolvedOptions));
    const verifyJWT = (token) => new Promise((resolve, reject) => {
        (0, jsonwebtoken_1.verify)(token, secret, forceHS512Verify(resolvedOptions), (err, value) => {
            if (err) {
                reject(err);
            }
            else {
                resolve(value);
            }
        });
    });
    return {
        MustAuthWithJWT: buildAuth(verifyJWT, api_1.ClassMiddleware, {
            loader,
            bearer,
            authCookieName,
        }),
        MustAuthRouteWithJWT: buildAuth(verifyJWT, api_1.Middleware, {
            loader,
            bearer,
            authCookieName,
        }),
        signJWT,
        verifyJWT,
    };
};
exports.authWithJWT = authWithJWT;
