"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRouteSnippets = exports.routemapToOpenAPI = exports.asOpenAPIPathParams = exports.asOpenAPIPath = exports.getRouteMap = void 0;
const lodash_1 = __importDefault(require("lodash"));
const openapi3_ts_1 = require("openapi3-ts");
// @ts-expect-error 7016
const openapi_snippet_1 = __importDefault(require("openapi-snippet"));
const path_to_regexp_1 = require("path-to-regexp");
const zod_openapi_1 = require("@anatine/zod-openapi");
require("reflect-metadata");
const getRouteMap = (controllers) => {
    const routemap = controllers
        .map((Cnt) => {
        const classKey = Reflect.getOwnMetadataKeys(Cnt.prototype).find((k) => k.toString().match(/Class Metadata/));
        const path = classKey
            ? Reflect.getOwnMetadata(classKey, Cnt.prototype).basePath
            : '';
        return {
            [Cnt.name]: {
                path,
                actions: Object.getOwnPropertyNames(Cnt.prototype)
                    .filter((p) => p !== 'constructor')
                    .map((p) => ({
                    meta: Reflect.getOwnMetadata(p, Cnt.prototype),
                    action: p,
                }))
                    .filter((desc) => desc.meta)
                    .map(({ meta, action }) => {
                    var _a;
                    return ({
                        action,
                        // decide and find the first schema around.
                        // each middleware, which is a function,
                        // can have a standardized 'params' field
                        schema: (_a = meta === null || meta === void 0 ? void 0 : meta.middlewares) === null || _a === void 0 ? void 0 : _a.map((m) => { var _a; return (_a = m.params) === null || _a === void 0 ? void 0 : _a.schema; }).find((s) => s),
                        routes: meta.httpRoutes.map((r) => ({
                            parsedPath: (0, path_to_regexp_1.parse)(path + r.path),
                            verb: r.httpDecorator,
                            path: r.path,
                        })),
                    });
                }),
            },
        };
    })
        .reduce((acc, m) => (Object.assign(Object.assign({}, acc), m)), {});
    return routemap;
};
exports.getRouteMap = getRouteMap;
const asOpenAPIPath = (parsedPath) => {
    return parsedPath
        .map((part) => (lodash_1.default.isString(part) ? part : `/{${part.name}}`))
        .join('');
};
exports.asOpenAPIPath = asOpenAPIPath;
const asOpenAPIPathParams = (parsedPath) => {
    return parsedPath
        .filter((part) => !lodash_1.default.isString(part))
        .map(({ name }) => ({
        name,
        schema: { type: 'string' },
        required: true,
        in: 'path',
    }));
};
exports.asOpenAPIPathParams = asOpenAPIPathParams;
const routemapToOpenAPI = (routemap, url = 'http://localhost:5150') => {
    const builder = openapi3_ts_1.OpenApiBuilder.create({
        openapi: '3.0.0',
        servers: [{ url }],
        info: {
            title: '',
            version: '',
        },
        paths: {},
    });
    lodash_1.default.forEach(routemap, (controller, _name) => {
        controller.actions.forEach((action) => {
            action.routes.forEach((route) => {
                /*
                ## parameter handling:
                * parse best effort from path (/foo/bar/:someId) -> 'someId' is a path param
                * if we have a schema for the action, translate from zod to OpenAPI and drop it inside
                  the params array as 'body'
                Note: action --*> route (there can be many routes on an action, but
                      there can be a single schema on an action)
                */
                var _a;
                const path = (0, exports.asOpenAPIPath)(route.parsedPath);
                const pathmap = builder.rootDoc.paths[path] || {};
                builder.addPath(path, Object.assign(Object.assign({}, pathmap), {
                    [route.verb.toString()]: Object.assign(Object.assign({ responses: {
                            '200': {
                                description: 'OK',
                            },
                        } }, (((_a = action.schema) === null || _a === void 0 ? void 0 : _a.zod) && {
                        requestBody: {
                            required: true,
                            content: {
                                'application/json': {
                                    schema: (0, zod_openapi_1.generateSchema)(action.schema.zod),
                                },
                            },
                        },
                    })), { parameters: (0, exports.asOpenAPIPathParams)(route.parsedPath) }),
                }));
            });
        });
    });
    return builder;
};
exports.routemapToOpenAPI = routemapToOpenAPI;
const getRouteSnippets = (routemap, verb, path, snippets = ['shell_curl'], url = 'http://localhost:5150') => {
    const api = (0, exports.routemapToOpenAPI)(routemap, url);
    const results = openapi_snippet_1.default.getEndpointSnippets(api.rootDoc, path, verb, snippets, {
        short: true,
    });
    return results;
};
exports.getRouteSnippets = getRouteSnippets;
