"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const responses_1 = require("../http/responses");
const response_sender_1 = __importDefault(require("../http/response-sender"));
const debug = (0, debug_1.default)('hypercontroller:error-handler');
const errorHandler = ({ logger, sendValidationErrors = false, }) => (err, req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    debug('error %o', err);
    debug('sending validation errors out? %o', sendValidationErrors);
    if (err instanceof responses_1.HttpResponse) {
        (0, response_sender_1.default)(res, err);
    }
    else if (err.isValidationError && sendValidationErrors) {
        (0, response_sender_1.default)(res, new responses_1.HttpResponseBadRequest({
            error: 'validation',
            validationErrors: err.errors,
        }));
    }
    else if (err.isModelError) {
        (0, response_sender_1.default)(res, new responses_1.HttpResponseBadRequest({ error: err.message }));
    }
    else if (err) {
        // prefer a request-bound logger because of occasional child loggers & context that's bound to these
        const resolvedLogger = req && req.logger ? req.logger : logger;
        if (resolvedLogger) {
            resolvedLogger.error({ err }, `Internal error`);
        }
        (0, response_sender_1.default)(res, new responses_1.HttpResponseBadRequest({ error: 'bad request' }));
    }
    else {
        next();
    }
});
exports.default = errorHandler;
